@@ -4,7 +4,7 @@
  *	  delete & vacuum routines for the postgres RUM
  *
  *
- * Portions Copyright (c) 2015-2016, Postgres Professional
+ * Portions Copyright (c) 2015-2019, Postgres Professional
  * Portions Copyright (c) 1996-2016, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
@@ -53,6 +53,7 @@ rumVacuumPostingList(RumVacuumState * gvs, OffsetNumber attnum, Pointer src,
 				prev,
 				ptr = src;
 
+	*newSize = 0;
 	ItemPointerSetMin(&item.iptr);
 
 	/*
@@ -63,7 +64,7 @@ rumVacuumPostingList(RumVacuumState * gvs, OffsetNumber attnum, Pointer src,
 	for (i = 0; i < nitem; i++)
 	{
 		prev = ptr;
-		ptr = rumDataPageLeafRead(ptr, attnum, &item, &gvs->rumstate);
+		ptr = rumDataPageLeafRead(ptr, attnum, &item, false, &gvs->rumstate);
 		if (gvs->callback(&item.iptr, gvs->callback_state))
 		{
 			gvs->result->tuples_removed += 1;
